clear
clear matrix
set mem 25m

use "Geopolitics of oil production - IO replication - 2013Mar.dta", clear

/* Analysis*/

** Basic Models
reg rate opec , cl(statenum)
estimates store bivariate
reg rate polity gr lnrpc risk war sanction , cl(statenum)
estimates store base
reg rate opec polity gr lnrpc risk war sanction , cl(statenum)
estimates store full
reg rate saudi opecnonsaudi polity gr risk lnrpc war sanction , cl(statenum)
estimates store saudi
reg rate saudi opecothercore opecnoncore polity gr risk lnrpc war sanction , cl(statenum)
estimates store core
reg rate opec polity gr lnrpc risk war sanction lift, cl(statenum)
estimates store lift
estimates table base full saudi core lift, star(0.1 0.05 0.01)

** Treating non-Saudi-OPEC depletion rate as real: cost-benefit analysis  
reg rate polity gr lnrpc risk war sanction , cl(statenum)
estimates store base
predict predrate if e(sample)
gen opecresid = (rate - predrate) if opecnonsaudi==1
mean opecresid
mean predrate if opecresid!=.
di -.228 / 3.456  /* On average, OPEC states underproduce by 6.6 percent of their predicted values */

** ROBUSTNESS  - see Table A2 
reg rate opec polity gr lnrpc risk war sanction, cl(statenum)
estimates store full
reg rate opec polity gr lnrpc risk war sanction inci, cl(statenum)
estimates store civilconflict
reg rate opec polity gr lnrpc risk war sanction warinci, cl(statenum)
estimates store civilwar
reg rate opeccore opecnoncore polity gr risk lnrpc war sanction , cl(statenum)
estimates store core
reg rate opec polity gr lnrpc risk war sanction price_const00, cl(statenum)
estimates store price
estimates table full civilconflict civilwar core price, star(0.10 0.05 0.01) 

** Time Periods
reg rate opecper1 opecper2 opecper3 opecper4 opecper5 opecper6 polityper1 polityper2 polityper3 polityper4 polityper5 polityper6 lnrpc1 lnrpc2 lnrpc3 lnrpc4 lnrpc5 lnrpc6 riskper1 riskper2 riskper3 riskper4 riskper5 riskper6 gr war sanction, cl(statenum)
estimates store periodsfull
reg rate opecper1 opecper2 opecper3 opecper4 opecper5 opecper6 polityper1 polityper2 polityper3 polityper4 polityper5 polityper6 lnrpc1 lnrpc2 lnrpc3 lnrpc4 lnrpc5 lnrpc6 riskper1 riskper2 riskper3 riskper4 riskper5 riskper6 gr war sanction spare opecspare, cl(statenum)
estimates store periodscap

** Year Dummies
reg rate opec polity gr lnrpc risk war sanction , cl(statenum)
reg rate opec polity gr lnrpc risk war sanction i.year, cl(statenum)

** Tobit model
reg rate opec polity gr lnrpc risk war sanction , cl(statenum)
tobit rate opec polity gr lnrpc risk war sanction, ll(0) ul(100) cl(statenum)

** Panel and fixed effects model
reg rate opec polity gr lnrpc risk war sanction , cl(statenum)
xtset statenum year
xtreg rate opec polity gr lnrpc risk war sanction , re
xtreg rate opec polity gr lnrpc risk war sanction , fe

** Spare capacity
reg rate opec polity gr lnrpc risk war sanction spare, cl(statenum)
reg rate opec polity gr lnrpc risk war sanction spare opecspare, cl(statenum)
reg rate opecper1 opecper2 opecper3 opecper4 opecper5 opecper6 polityper1 polityper2 polityper3 polityper4 polityper5 polityper6 lnrpc1 lnrpc2 lnrpc3 lnrpc4 lnrpc5 lnrpc6 riskper1 riskper2 riskper3 riskper4 riskper5 riskper6 gr war sanction spare opecspare, cl(statenum)

** Production models
reg prod res polity gr lnrpc risk war sanction , cl(statenum)
estimates store base
reg prod res opec polity gr lnrpc risk war sanction , cl(statenum)
estimates store full
reg prod res opeccore opecnoncore polity gr risk lnrpc war sanction , cl(statenum)
estimates store core
reg prod res saudi opecnonsaudi polity gr risk lnrpc war sanction , cl(statenum)
estimates store saudi
reg prod res opec polity gr lnrpc risk war sanction lift, cl(statenum)
estimates store lift
estimates table base full saudi core lift, star(0.1 0.05 0.01)
